==> theme-bootstrap-1.0.71.tgz: package/src/helpers/pin-code.test.js <==
import { isPinValid, encryptPinCode, isPinSymbolsValid } from './pin-code';

describe('Pin code utils', () => {
  describe('#isPinValid', () => {
    test('should return true for 9 digit number pin', () => {
      expect(isPinValid(12345678)).toBe(true);
    });

    test('should return false for invalid pins', () => {
      expect(isPinValid(1234567)).toBe(false);
      expect(isPinValid(123456789)).toBe(false);
      expect(isPinValid()).toBe(false);
      expect(isPinValid('f2fef2f2e')).toBe(false);
      expect(isPinValid('1234656!3')).toBe(false);
    });
  });

  describe('#isPinSymbolsValid', () => {
    test('should return true for any number', () => {
      expect(isPinSymbolsValid(123)).toBe(true);
      expect(isPinSymbolsValid(55)).toBe(true);
      expect(isPinSymbolsValid('12312312')).toBe(true);
    });

    test('should return false for any symbols other than numbers', () => {
      expect(isPinSymbolsValid('a')).toBe(false);
      expect(isPinSymbolsValid('af23f2')).toBe(false);
      expect(isPinSymbolsValid('123123!')).toBe(false);
      expect(isPinSymbolsValid('_')).toBe(false);
    });
  });

  describe('#encryptPinCode', () => {
    const pinCode = '12345678';
    const encrypted = encryptPinCode(pinCode);

    test('should be more than zero length', () => {
      expect(encrypted.length).toBeGreaterThan(0);
    });

    test('should not equal encrypted to pin', () => {
      expect(encrypted !== pinCode);
    });

    test('should be same for another encryption for same code', () => {
      expect(encryptPinCode(pinCode)).toEqual(encrypted);
    });
  });
});

==> theme-bootstrap-2.0.28.tgz: package/src/helpers/pin-code.test.js <==
import { isPinValid, encryptPinCode, isPinSymbolsValid } from './pin-code';

describe('Pin code utils', () => {
  describe('#isPinValid', () => {
    test('should return true for 9 digit number pin', () => {
      expect(isPinValid(12345678)).toBe(true);
    });

    test('should return false for invalid pins', () => {
      expect(isPinValid(1234567)).toBe(false);
      expect(isPinValid(123456789)).toBe(false);
      expect(isPinValid()).toBe(false);
      expect(isPinValid('f2fef2f2e')).toBe(false);
      expect(isPinValid('1234656!3')).toBe(false);
    });
  });

  describe('#isPinSymbolsValid', () => {
    test('should return true for any number', () => {
      expect(isPinSymbolsValid(123)).toBe(true);
      expect(isPinSymbolsValid(55)).toBe(true);
      expect(isPinSymbolsValid('12312312')).toBe(true);
    });

    test('should return false for any symbols other than numbers', () => {
      expect(isPinSymbolsValid('a')).toBe(false);
      expect(isPinSymbolsValid('af23f2')).toBe(false);
      expect(isPinSymbolsValid('123123!')).toBe(false);
      expect(isPinSymbolsValid('_')).toBe(false);
    });
  });

  describe('#encryptPinCode', () => {
    const pinCode = '12345678';
    const encrypted = encryptPinCode(pinCode);

    test('should be more than zero length', () => {
      expect(encrypted.length).toBeGreaterThan(0);
    });

    test('should not equal encrypted to pin', () => {
      expect(encrypted).not.toEqual(pinCode);
    });

    test('should be same for another encryption for same code', () => {
      expect(encryptPinCode(pinCode)).toEqual(encrypted);
    });
  });
});
